Exception: Amfetamine::UnknownRESTMethod
- Inherits:
-
Exception
- Object
- Exception
- Amfetamine::UnknownRESTMethod
- Defined in:
- lib/amfetamine/exceptions.rb
Overview
Only used if rest method is not handled by amfetamine
Only used if rest method is not handled by amfetamine